==> haskell-hslua-classes-2.3.0-85-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-classes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-classes
version:              2.3.0
visibility:           public
id:                   hslua-classes-2.3.0-7j99SEgD4wg5JQI35DqlPl
key:                  hslua-classes-2.3.0-7j99SEgD4wg5JQI35DqlPl
license:              MIT
copyright:
    © 2007–2012 Gracjan Polak;
    © 2012–2016 Ömer Sinan Ağacan;
    © 2017-2023 Albert Krewinkel

maintainer:           tarleb@hslua.org
author:               Albert Krewinkel, Gracjan Polak, Ömer Sinan Ağacan
homepage:             https://hslua.org/
synopsis:             Type classes for HsLua
description:
    Type classes for convenient marshalling and calling of
    Lua functions.

category:             Foreign
abi:                  267fd3f12f3b418f30fcc0f34c0ab73d
exposed:              True
exposed-modules:
    HsLua.Class.Exposable HsLua.Class.Invokable HsLua.Class.Peekable
    HsLua.Class.Pushable HsLua.Class.Util HsLua.Classes

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-classes-2.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-classes-2.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-classes-2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-classes
hs-libraries:         HShslua-classes-2.3.0-7j99SEgD4wg5JQI35DqlPl
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    exceptions-0.10.5 hslua-core-2.3.1-35UTfP2LiNCBMxd2Ioavvt
    hslua-marshalling-2.3.1-9zCRQ0YgOdf7ziYBQDid8N text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-classes/html/hslua-classes.haddock

haddock-html:         /usr/share/doc/haskell-hslua-classes/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-classes-2.3.0-86-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-classes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-classes
version:              2.3.0
visibility:           public
id:                   hslua-classes-2.3.0-E6Ka7ahM59iHYZctsIoIYg
key:                  hslua-classes-2.3.0-E6Ka7ahM59iHYZctsIoIYg
license:              MIT
copyright:
    © 2007–2012 Gracjan Polak;
    © 2012–2016 Ömer Sinan Ağacan;
    © 2017-2023 Albert Krewinkel

maintainer:           tarleb@hslua.org
author:               Albert Krewinkel, Gracjan Polak, Ömer Sinan Ağacan
homepage:             https://hslua.org/
synopsis:             Type classes for HsLua
description:
    Type classes for convenient marshalling and calling of
    Lua functions.

category:             Foreign
abi:                  fad2a183bad330cdfe51e51afa5d43b2
exposed:              True
exposed-modules:
    HsLua.Class.Exposable HsLua.Class.Invokable HsLua.Class.Peekable
    HsLua.Class.Pushable HsLua.Class.Util HsLua.Classes

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-classes-2.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-classes-2.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-classes-2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-classes
hs-libraries:         HShslua-classes-2.3.0-E6Ka7ahM59iHYZctsIoIYg
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    exceptions-0.10.5 hslua-core-2.3.1-5G0x5hmdcWo3nepPHPVU6r
    hslua-marshalling-2.3.1-GimNUqUlRmSBGwZwedlMIF text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-classes/html/hslua-classes.haddock

haddock-html:         /usr/share/doc/haskell-hslua-classes/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
